#!/bin/bash
# 	PROBOTIX LinuxCNC Configurator
#		zip file created Fri Apr  8 19:35:56 EDT 2016
#
# 	Copyright 2016 PROBOTIX
# 	Written by Len Shelton
# 	Version 1.0 release  Mar 29 2016
#
#	Rev1.1 	Bug fixes
#	Rev1.2	Bug Fixes
#	Rev1.3 	Added PyVCP buttons
#		Hard Coded G28 & G30 buttons to G53 coordinates
#		Hard Coded ATLaS location to G53 coordinates
#		Fixed o102 bug
#		Consolidated o100 & o101
#	Rev1.4 	Added php installer
#		Added lspci dump to text file
#		Misc bug fixes
#		Fix o100: check for already tool loaded and measured
#
#	Todo: 	Fix RS274_STARTUP_CODE to clear tool and offset
#		Clear preview history after homing
#		Make insmod edimax permanent
#		Probe from shorter height
#		Z-axis min limit fix
#		Add key bindings for rotary jog
#		Add support for older gamepads
#		Check for error on script keyboard input
#		Finish ngc2 filter
#		Rotate g-code functions 
#		Fix sample g-code programs
#		Increase debounce time for limits only
#
#
VERSION="1.5"

INSTALLDIR=$(pwd)
DATETIME=$(date +%m%d%Y%H%M%S)
REBOOT=0
CONFIG_FILE="/home/probotix/LINUXCNC_CONFIG"





#push password into sudo so that it doesnt prompt for it later
sudo -S <<< "probotix" clear

#set the terminal defaults so that we have classic green on black colors
gconftool-2 --set /apps/gnome-terminal/profiles/Default/use_theme_colors --type bool "false" 
gconftool-2 --set /apps/gnome-terminal/profiles/Default/use_theme_background --type bool "false" 
gconftool-2 --set /apps/gnome-terminal/profiles/Default/foreground_color --type string "#0000FFFF0000"
gconftool-2 --set /apps/gnome-terminal/profiles/Default/background_color --type string "#000000000000"



if ( whoami != probotix )
then
	echo "Not running as user probotix! Call PROBOTIX 309-691-2643"
	sleep 10 
	exit
fi

if [ -d "/home/probotix" ]
then
	clear	
else 
	echo "Probotix directory not found! Call PROBOTIX 309-691-2643"
	sleep 10 
	exit
fi

if [ -d "/home/probotix/emc2" ]
then
	echo "EMC2 directory found! Call PROBOTIX 309-691-2643"
	sleep 10 
	exit
fi

if [ -e $CONFIG_FILE ]
then
	#config exists
	echo "$CONFIG_FILE found!"
	rm -f $CONFIG_FILE
	sleep 3
fi

if [ -L /usr/bin/axis ]
then 
	echo "/usr/bin/axis is symlink"
	tar -czvf /home/probotix/.backup.$DATETIME.tar.gz /home/probotix/linuxcnc/
	echo "Configuration Backup Created!"
else
	#make a backup of the original axis files
	tar -czvf /home/probotix/.backup.axis.tar.gz /usr/bin/axis /usr/share/axis /home/probotix/linuxcnc/
	echo "NEW Configuration Backup Created!"
fi



# create config file
echo "DATE=$DATETIME" >> $CONFIG_FILE
echo "VERSION=$VERSION" >> $CONFIG_FILE
sleep 3



#set num lock   
if [ -e "/usr/bin/numlockx" ]
then 
	numlockx	
else
	cd .numlockx 
	sudo ./configure
	sudo make
	sudo make install
	cd ..
	numlockx
fi

# install php so that future versions will be able to use php scripting
if $(command -v php >/dev/null)
then
#	echo $( command -v php )
	echo "php installed"
else
	echo "no php"
	cd .php/
	sudo dpkg -i php5-common_5.3.2-1ubuntu4.30_i386.deb
	sudo dpkg -i php5-cli_5.3.2-1ubuntu4.30_i386.deb
	echo "php installed"
	sleep 3
	cd ..
fi

if [ -d "/home/probotix/bin" ]
then
	cp -f .g-code-filter.php /home/probotix/bin/g-code-filter.php
else
	mkdir -p /home/probotix/bin
	cp -f .g-code-filter.php /home/probotix/bin/g-code-filter.php
	REBOOT=1
fi


# this section tries to identify the add-on parallel port address
LSPCI=$(lspci -v | grep NetMos)
lspci -v > ./LSPCI.txt
#echo $LSPCI 
# get substring
SUB=${LSPCI:0:7}
#echo $SUB
ADDR=$(dmesg | grep $SUB)
A=${ADDR#*0x}
B=${A:0:4}
# hopefully this will be the variable for the second parallel port
IDENT="0x"$B
LEN=${#IDENT}
#echo $LEN
#sleep 100
if [ $LEN -eq 6 ]
then 
    	IDENTB=$IDENT
else
	IDENTB="0xd050"
fi

#set the default editor for .ngc files
sudo cp -f .freedesktop.org.xml /usr/share/mime/packages/freedesktop.org.xml 
sudo update-mime-database /usr/share/mime






clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
echo "Enter Order Number:"
read ORDER_NO
#echo $ORDER_NO >> log.txt
echo "ORDER_NO=$ORDER_NO" >> $CONFIG_FILE

rm -Rf /home/probotix/Desktop/*.desktop

rm -Rf /home/probotix/linuxcnc
mkdir  -p /home/probotix/linuxcnc
mkdir  -p /home/probotix/linuxcnc/configs
mkdir  -p /home/probotix/linuxcnc/configs/PROBOTIX
mkdir  -p /home/probotix/linuxcnc/configs/PROBOTIX/axis
mkdir  -p /home/probotix/linuxcnc/nc_files
cp -R .nc_files/* /home/probotix/linuxcnc/nc_files
sudo cp .probotix_splash.gif /usr/share/linuxcnc/probotix_splash.gif

#create symlink to axis program
sudo rm -f /usr/bin/axis
sudo rm -Rf /usr/share/axis
cp -Rud .axis_files/axis/* /home/probotix/linuxcnc/configs/PROBOTIX/axis/
sudo ln -s /home/probotix/linuxcnc/configs/PROBOTIX/axis/axis /usr/bin/axis
sudo ln -s /home/probotix/linuxcnc/configs/PROBOTIX/axis /usr/share/axis

#create link to nc_files on desktop
rm -f /home/probotix/Desktop/nc_files
ln -sf /home/probotix/linuxcnc/nc_files/ /home/probotix/Desktop/nc_files


#set desktop background
SCREEN_WIDTH=$(xrandr --current | grep '*' | uniq | awk '{print $1}' | cut -d 'x' -f1)
cp -f .$SCREEN_WIDTH*probotix_background.png /home/probotix/Pictures/.background.png
gconftool-2 -t string -s /desktop/gnome/background/picture_filename /home/probotix/Pictures/.background.png
echo "SCREEN_WIDTH=$SCREEN_WIDTH" >> $CONFIG_FILE




gconftool-2 --type bool --set /apps/gnome-screensaver/lock_enabled 0
gconftool-2 --type bool --set /apps/gnome-screensaver/idle_activation_enabled 0
gconftool-2 --type bool --set /apps/gedit-2/preferences/editor/line_numbers/display_line_numbers true
sudo apt-get -qq -y remove update-manager

clear



echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Choose your machine:"
select x in "V90mk2" "Comet" "Asteroid" "Meteor" "Nebula/MeteorXL" "Custom";
do
    case $x in
	V90mk2 ) 	MACHINE="V90MK2"; 
			X_MAX_LIMIT=20.25
			Y_MAX_LIMIT=13.5
			break;;
	Comet ) 	MACHINE="COMET";
			X_MAX_LIMIT=26.125
			Y_MAX_LIMIT=25.1152
			break;;
        Asteroid ) 	MACHINE="ASTEROID"; 
			X_MAX_LIMIT=37.25
			Y_MAX_LIMIT=25.1152
			break;;
	Meteor ) 	MACHINE="METEOR"; 
			X_MAX_LIMIT=26.125
			Y_MAX_LIMIT=52.2
			break;;
	"Nebula/MeteorXL" ) 	MACHINE="NEBULA"; 
			X_MAX_LIMIT=37.25
			Y_MAX_LIMIT=52.2
			break;;
	Custom ) 	MACHINE="CUSTOM"; 
			#X_MAX_LIMIT=37.25
			#Y_MAX_LIMIT=52.2
			break;;
    esac
done
echo "MACHINE=$MACHINE" >> $CONFIG_FILE


cp .PROBOTIX.ini .TEMP.ini
cp .PROBOTIX.hal .TEMP.hal
cp .PANEL.xml .TEMP.xml
cp .POSTGUI.hal .TEMPpostgui.hal
cp .102.ngc .TEMP102.ngc
cp .100.ngc .TEMP100.ngc
cp .emc.var .TEMPemc.var



clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Choose your spindle:"
select x in "Router" "VFD Spindle";
do
    case $x in
	"Router" ) 	SPINDLE="ROUTER"
			
			#remove spindle speed
			sed -i '/PWM/,+5d' .TEMP.hal
                        sed -i '/SPINDLE/,+16d' .TEMP.hal
			sed -i '/SPINDLE_SPEED/,+13d' .TEMP.xml 
			sed -i '/VFD/,+3d' .TEMPpostgui.hal
			break;;
        "VFD Spindle" ) SPINDLE="VFD"
			sed -i '/ROUTER/,+7d' .TEMP.hal			
			break;;

    esac
done
echo "SPINDLE=$SPINDLE" >> $CONFIG_FILE

ATLAS_X="0.075"
ATLAS_Y="3.5533"
# Short mounts are -0.165 shorter from Y center

if [ $SPINDLE = "ROUTER" ]
then 
clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
echo "Short or Long Router Mount?"
select x in "Short" "Long";
do
    case $x in
	"Short" ) 	ROUTER_MOUNT="SHORT"
			ATLAS_Y="3.3883"
			break;;
        "Long" ) 	ROUTER_MOUNT="LONG"
			ATLAS_Y="3.5533"
			break;;

    esac
done
fi


clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Choose your units:"
select x in "Inch" "Metric";
do
    case $x in
	Inch ) 		UNITS="inch"; 
			I=1
			REPLACE_RSC="G17 G20 G40 G49 G54 G90 G64 P0.001 T0"
			REPLACE_INC=".1in .05in .01in .005in .001in"
			UNIT_DESC="(X.XXX in inches)"
			UNIT_DESC_BIG="(XX.XXX in inches)"
			ZPUCK_DIST=5
			ZPUCK_FEED=10
			GUNITS="G20"
			break;;
        Metric ) 	UNITS="mm"; 
			I=25.4
			REPLACE_RSC="G17 G21 G40 G49 G54 G90 G64 P0.03 T0"
			UNIT_DESC="(XX.XX in mm)"
			UNIT_DESC_BIG="(XXXX.XX in mm)"
			REPLACE_INC="10mm 5mm 1mm 0.1mm 0.01mm"
			ATLAS_X=$(expr "scale=4; $ATLAS_X*$I" | bc -l)
			ATLAS_Y=$(expr "scale=4; $ATLAS_Y*$I" | bc -l)
			ZPUCK_DIST=127
			ZPUCK_FEED=254
			GUNITS="G21"
			break;;

    esac
done
echo "UNITS=$UNITS" >> $CONFIG_FILE

sed -i -e 's/REPLACE_ATLAS_X/'"$ATLAS_X"'/' .TEMP100.ngc
sed -i -e 's/REPLACE_ATLAS_Y/'"$ATLAS_Y"'/' .TEMP100.ngc
sed -i -e 's/REPLACE_ATLAS_X/'"$ATLAS_X"'/' .TEMPemc.var
sed -i -e 's/REPLACE_ATLAS_Y/'"$ATLAS_Y"'/' .TEMPemc.var

if [ $MACHINE = "CUSTOM" ]
then
	clear
	echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
	#sleep 0.5
	echo "Enter X-Axis Max Travel $UNIT_DESC_BIG"
	read X_MAX_LIMIT
	clear
	echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
	#sleep 0.5
	echo "Enter Y-Axis Max Travel $UNIT_DESC_BIG"
	read Y_MAX_LIMIT
	# if custom machine, use input values instead of calculated
else
	# otherwise use calculated values to adjust for metric
	X_MAX_LIMIT=$(expr "scale=4; $X_MAX_LIMIT*$I" | bc -l)
	Y_MAX_LIMIT=$(expr "scale=4; $Y_MAX_LIMIT*$I" | bc -l)
fi
echo "X_MAX_LIMIT=$X_MAX_LIMIT" >> $CONFIG_FILE
echo "Y_MAX_LIMIT=$Y_MAX_LIMIT" >> $CONFIG_FILE


X_PARK=$(expr "scale=4; $X_MAX_LIMIT/2" | bc -l)
Y_PARK=$(expr "$Y_MAX_LIMIT-(0.1*$I)" | bc -l)
Z_MIN_LIMIT=$(expr 5.7*$I | bc -l)
echo "Z_MIN_LIMIT=$Z_MIN_LIMIT" >> $CONFIG_FILE
echo "X_PARK=$X_PARK" >> $CONFIG_FILE



#sleep 10
clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Choose your ACME screw:"
select x in "Roton" "Helix";
do
    case $x in
	Roton ) 	ACME="ROTON"; 
			ZTPI=5
			Z_MAXVEL=0.4
			# 24IPM Z-Axis
			sed -i -e 's/REPLACE_ZVELOCITY/0.4/' .TEMP.ini
			break;;
        Helix ) 	ACME="HELIX"; 
			ZTPI=2
			Z_MAXVEL=3
			#180IPM Z-Axis
			sed -i -e 's/REPLACE_ZVELOCITY/3/' .TEMP.ini
			break;;

    esac
done
echo "ACME=$ACME" >> $CONFIG_FILE

clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Choose your drivers:"
select x in "ProboStep" "MondoStep";
do
    case $x in
	ProboStep ) 	DRIVERS="PROBOSTEP";
			XYSCALE=$(expr "scale=4; 2*200*2/$I" | bc -l)
			ZSCALE=$(expr "scale=4; 2*200*$ZTPI/$I" | bc -l)
			break;;
        MondoStep ) 	DRIVERS="MONDOSTEP"; 
			XYSCALE=$(expr "scale=4; 4*200*2/$I" | bc -l)
			ZSCALE=$(expr "scale=4; 4*200*$ZTPI/$I" | bc -l)
			break;;

    esac
done
echo "DRIVERS=$DRIVERS" >> $CONFIG_FILE





clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Do you use the GamePad?"
select x in "Yes" "No";
do
    case $x in
	Yes ) 	GAMEPAD="YES"
		break;;
        No ) 	GAMEPAD="NO"
		#remove gamepad from hal file
		sed -i '/GAMEPAD/,+1d' .TEMP.hal	
		sed -i '/GAMEPAD/,+31d' .TEMPpostgui.hal

		break;;

    esac
done
echo "GAMEPAD=$GAMEPAD" >> $CONFIG_FILE

PARPORT0="0x378"
PARPORT1=$IDENTB

clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "PARPORT.0 $PARPORT0, PARPORT.1 $PARPORT1 Okay?"
select x in "Yes" "No";
do
    case $x in
	Yes ) 	
		break;;
        No ) 	clear
		echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
		echo "Enter PARPORT0:"
		read PARPORT0
		clear
		echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
		echo "Enter PARPORT1:"
		read PARPORT1	
		break;;
    esac
done



clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Do you use the ATLaS Tool Length Sensor or the Z-Puck?"
select x in "ATLaS only" "Z-Puck only" "Both" "None" "Swap Parallel Ports";
do
    case $x in
	"ATLaS only" ) 		SENSOR="ATLAS"; 

				#remove zpuck control
				sed -i '/ZPUCK/,+5d' .TEMP.xml
				sed -i '/HALUI_ZPUCK/,+1d' .TEMPpostgui.hal
				sed -i -e 's/REPLACE_GUNITS/'"$GUNITS"'/' \
					-e 's/REPLACE_ZMIN/'"$Z_MIN_LIMIT"'/' \
					-e 's/REPLACE_MULTIPLIER/'"$I"'/' \
					-e 's/REPLACE_X_PARK/'"$X_PARK"'/' .TEMP100.ngc

				break;;
        "Z-Puck only" ) 	SENSOR="Z-Puck"; 
				clear
				echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
				#sleep 0.5
				echo "Enter Height of Z-Puck $UNIT_DESC"
				read ZPUCK
				sed -i -e 's/REPLACE_ZP_HEIGHT/'"$ZPUCK"'/' \
				       -e 's/REPLACE_ZP_DIST/'"$ZPUCK_DIST"'/' \
				       -e 's/REPLACE_ZP_FEED/'"$ZPUCK_FEED"'/' \
				       -e 's/REPLACE_GUNITS/'"$GUNITS"'/' .TEMP102.ngc
				#remove atlas
				sed -i '/ATLAS/,+5d' .TEMP.xml
				sed -i '/HALUI_FIRST_TOOL/,+1d' .TEMPpostgui.hal
				
				break;;
	"Both" )		SENSOR="BOTH";
				clear
				echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
				#sleep 0.5
				echo "Enter Height of Z-Puck $UNIT_DESC"
				read ZPUCK
				sed -i -e 's/REPLACE_ZP_HEIGHT/'"$ZPUCK"'/' \
				       -e 's/REPLACE_ZP_DIST/'"$ZPUCK_DIST"'/' \
				       -e 's/REPLACE_ZP_FEED/'"$ZPUCK_FEED"'/' \
				       -e 's/REPLACE_GUNITS/'"$GUNITS"'/' .TEMP102.ngc
				sed -i -e 's/REPLACE_GUNITS/'"$GUNITS"'/' \
					-e 's/REPLACE_ZMIN/'"$Z_MIN_LIMIT"'/' \
					-e 's/REPLACE_MULTIPLIER/'"$I"'/' \
					-e 's/REPLACE_X_PARK/'"$X_PARK"'/' .TEMP100.ngc
				break;;
	"None" )		SENSOR="NONE";
				#remove probe indicator
				sed -i '/PROBE/,+15d' .TEMP.xml
				sed -i '/PROBE_LED/,+1d' .TEMPpostgui.hal			
				#remove zpuck control
				sed -i '/ZPUCK/,+5d' .TEMP.xml
				sed -i '/HALUI_ZPUCK/,+1d' .TEMPpostgui.hal
				#remove atlas
				sed -i '/ATLAS/,+5d' .TEMP.xml
				sed -i '/HALUI_FIRST_TOOL/,+1d' .TEMPpostgui.hal
				break;;
	"Swap Parallel Ports" ) SENSOR="NONE";
				#remove probe indicator
				sed -i '/PROBE/,+15d' .TEMP.xml
				sed -i '/PROBE_LED/,+1d' .TEMPpostgui.hal			
				#remove zpuck control
				sed -i '/ZPUCK/,+5d' .TEMP.xml
				sed -i '/HALUI_ZPUCK/,+1d' .TEMPpostgui.hal
				#remove atlas
				sed -i '/ATLAS/,+5d' .TEMP.xml
				sed -i '/HALUI_FIRST_TOOL/,+1d' .TEMPpostgui.hal
				PARPORT0=$IDENTB
				PARPORT1=0x378
				break;;
    esac
done
echo "PARPORT0=$PARPORT0" >> $CONFIG_FILE
echo "PARPORT1=$PARPORT1" >> $CONFIG_FILE


sed -i -e "s/PARPORT0/$PARPORT0/" \
       -e "s/PARPORT1/$PARPORT1/" .TEMP.hal


clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Do you have the rotary axis?"
select xa in "Yes" "No";
do
    case $xa in
	Yes ) 	COORDINATES="X Y Z A"; 
		COORDINATES_="X\ Y\ Z\ A"; 
		AXES="4"; 
		break;;
        No ) 	COORDINATES="X Y Z"; 
		COORDINATES_="X\ Y\ Z"; 
		AXES="3"; 
		#remove a-axis from ini file
		sed -i '/AXIS_3/,+10d' .TEMP.ini
		#remove a-axis from hal file
		sed -i '/A-AXIS/,+13d' .TEMP.hal
		break;;
    esac
done
echo "COORDINATES=$COORDINATES" >> $CONFIG_FILE


XSTEP="02"
XDIR="03"
Y1STEP="04"
Y1DIR="05"
Y2STEP="08"
Y2DIR="09"
ZSTEP="06"
ZDIR="07"
ASTEP="17"
ADIR="01"

clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Do you want to swap a motor to the A-axis output?"
select x in "X" "Y1" "Y2" "Z" "No";
do
    case $x in
	X ) 	XSTEP="17"
                XDIR="01"
                COORDINATES="X Y Z"; 
		COORDINATES_="X\ Y\ Z"; 
		AXES="3"; 
		#remove a-axis from ini file
		sed -i '/AXIS_3/,+10d' .TEMP.ini
		#remove a-axis from hal file
		sed -i '/A-AXIS/,+13d' .TEMP.hal	
		break;;
	Y1 ) 	Y1STEP="17"
                Y1DIR="01"
                COORDINATES="X Y Z"; 
		COORDINATES_="X\ Y\ Z"; 
		AXES="3"; 
		#remove a-axis from ini file
		sed -i '/AXIS_3/,+10d' .TEMP.ini
		#remove a-axis from hal file
		sed -i '/A-AXIS/,+13d' .TEMP.hal	
		break;;
	Y2 ) 	Y2STEP="17"
                Y2DIR="01"
                COORDINATES="X Y Z"; 
		COORDINATES_="X\ Y\ Z"; 
		AXES="3"; 
		#remove a-axis from ini file
		sed -i '/AXIS_3/,+10d' .TEMP.ini
		#remove a-axis from hal file
		sed -i '/A-AXIS/,+13d' .TEMP.hal	
		break;;
	Z ) 	ZSTEP="17"
                ZDIR="01"
                COORDINATES="X Y Z"; 
		COORDINATES_="X\ Y\ Z"; 
		AXES="3"; 
		#remove a-axis from ini file
		sed -i '/AXIS_3/,+10d' .TEMP.ini
		#remove a-axis from hal file
		sed -i '/A-AXIS/,+13d' .TEMP.hal	
		break;;
        No ) 	
		break;;
    esac
done
echo "SWAP_TO_A=$x" >> $CONFIG_FILE

# markers for any swapped axis are already removed, sed will ignore those axes
sed -i -e "s/XSTEP/$XSTEP/" \
       -e "s/XDIR/$XDIR/" \
       -e "s/Y1STEP/$Y1STEP/" \
       -e "s/Y1DIR/$Y1DIR/" \
       -e "s/Y2STEP/$Y2STEP/" \
       -e "s/Y2DIR/$Y2DIR/" \
       -e "s/ZSTEP/$ZSTEP/" \
       -e "s/ZDIR/$ZDIR/" \
       -e "s/ASTEP/$ASTEP/" \
       -e "s/ADIR/$ADIR/" .TEMP.hal


clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
echo "Do you want to use soft limits only?"
select x in "Yes" "No";
do
    case $x in
	Yes ) 	sed -i '/LIMITS/,+5d' .TEMP.hal
		break;;
        No ) 	
		break;;
    esac
done
echo "SOFT_ONLY=$x" >> $CONFIG_FILE





clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
#sleep 0.5
#echo "Config Dump:"
echo "ORDER_NO     =" $ORDER_NO >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "MACHINE     =" $MACHINE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "UNITS       =" $UNITS >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ACME        =" $ACME >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "DRIVERS     =" $DRIVERS >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "SPINDLE     =" $SPINDLE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "GAMEPAD     =" $GAMEPAD >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "SENSOR      =" $SENSOR >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "AXES        =" $AXES >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "COORDINATES =" $COORDINATES >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ZPUCK       =" $ZPUCK >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XYSCALE     =" $XYSCALE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ZSCALE      =" $ZSCALE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ZTPI        =" $ZTPI >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "PARPORT0    =" $PARPORT0 >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO   
echo "PARPORT1    =" $PARPORT1 >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO

# metricify some additional axis vars
# floating point math is hoaky in bash, must us bc (bash calculator)
XY_MAXVEL=$(expr 3.34*$I | bc -l)
Z_MAXVEL=$(expr $Z_MAXVEL*$I | bc -l)
XY_MAXACCEL=$(expr 6*$I | bc -l)
Z_MAXACCEL=$(expr 10*$I | bc -l)
XY_STEPGEN_MAXACCEL=$(expr 15*$I | bc -l)
Z_STEPGEN_MAXACCEL=$(expr 15*$I | bc -l)
XY_MIN_LIMIT=$(expr 0.1*$I | bc -l)

Z_MAX_LIMIT=$(expr 0.1*$I | bc -l)
XY_HOME_OFFSET=$(expr 0.2*$I | bc -l)
Z_HOME_OFFSET=$(expr 0.2*$I | bc -l)
XY_SEARCH_VEL=$(expr 0.5*$I | bc -l)
Z_SEARCH_VEL=$(expr 0.5*$I | bc -l)
XY_LATCH_VEL=$(expr 0.2*$I | bc -l)
Z_LATCH_VEL=$(expr 0.2*$I | bc -l)
DEFAULT_VELOCITY=$(expr 3.34*$I | bc -l)
MAX_LINEAR_VELOCITY=$(expr 3.34*$I | bc -l)


echo "MACHINE     =" $MACHINE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "UNITS       =" $UNITS >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ACME        =" $ACME >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "DRIVERS     =" $DRIVERS >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "SPINDLE     =" $SPINDLE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "GAMEPAD     =" $GAMEPAD >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "SENSOR      =" $SENSOR >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "AXES        =" $AXES >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "COORDINATES =" $COORDINATES >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ZPUCK       =" $ZPUCK >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XYSCALE     =" $XYSCALE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ZSCALE      =" $ZSCALE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ZTPI        =" $ZTPI >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "PARPORT0    =" $PARPORT0 >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO   
echo "PARPORT1    =" $PARPORT1 >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XYSCALE     =" $XYSCALE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "ZSCALE      =" $ZSCALE >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XY_MAXVEL   =" $XY_MAXVEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Z_MAXVEL    =" $Z_MAXVEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XY_MAXACCEL =" $XY_MAXACCEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Z_MAXACCEL  =" $Z_MAXACCEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XY_SMAX_ACC =" $XY_STEPGEN_MAXACCEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Z_SMAX_ACC  =" $Z_STEPGEN_MAXACCEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XY_MIN_LIMIT=" $XY_MIN_LIMIT >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Z_MIN_LIMIT =" $Z_MIN_LIMIT >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "X_MAX_LIMIT =" $X_MAX_LIMIT >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Y_MAX_LIMIT =" $Y_MAX_LIMIT >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Z_MAX_LIMIT =" $Z_MAX_LIMIT >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XY_HM_OFFSET=" $XY_HOME_OFFSET >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Z_HM_OFFSET =" $Z_HOME_OFFSET >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XY_SEARCH_VL=" $XY_SEARCH_VEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Z_SEARCH_VEL=" $Z_SEARCH_VEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "XY_LATCH_VEL=" $XY_LATCH_VEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "Z_LATCH_VEL =" $Z_LATCH_VEL >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "DEF_VELOCITY=" $DEFAULT_VELOCITY >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO
echo "MAX_LIN_VEL =" $MAX_LINEAR_VELOCITY >> .CONFIGS/CONFIG_DUMP-.$ORDER_NO


# was 0.08
FERROR=$(expr 0.08*$I | bc -l)
#was 0.05
MIN_FERROR=$(expr 0.05*$I | bc -l)


# a-axis is in degrees, so no metrification necessary


#sleep 100

# replace vars in ini file - single + double quote to expand vars and escape spaces
sed -i -e 's/REPLACE_MACHINE/'"$MACHINE"'/' \
    -e 's/REPLACE_DEFAULT_VELOCITY/'"$DEFAULT_VELOCITY"'/' \
    -e 's/REPLACE_MAX_LINEAR_VELOCITY/'"$MAX_LINEAR_VELOCITY"'/' \
    -e 's/REPLACE_FERROR/'"$FERROR"'/' \
    -e 's/REPLACE_MIN_FERROR/'"$MIN_FERROR"'/' \
    -e 's/REPLACE_AXES/'"$AXES"'/' \
    -e 's/REPLACE_COORDINATES/'"$COORDINATES_"'/' \
    -e 's/REPLACE_UNITS/'"$UNITS"'/' \
    -e 's/REPLACE_XY_SCALE/'"$XYSCALE"'/' \
    -e 's/REPLACE_Z_SCALE/'"$ZSCALE"'/' \
    -e 's/REPLACE_XY_MAXVEL/'"$XY_MAXVEL"'/' \
    -e 's/REPLACE_Z_MAXVEL/'"$Z_MAXVEL"'/' \
    -e 's/REPLACE_XY_MAXACCEL/'"$XY_MAXACCEL"'/' \
    -e 's/REPLACE_Z_MAXACCEL/'"$Z_MAXACCEL"'/' \
    -e 's/REPLACE_XY_STEPGEN_MAXACCEL/'"$XY_STEPGEN_MAXACCEL"'/' \
    -e 's/REPLACE_Z_STEPGEN_MAXACCEL/'"$XY_STEPGEN_MAXACCEL"'/' \
    -e 's/REPLACE_XY_MIN_LIMIT/'"$XY_MIN_LIMIT"'/' \
    -e 's/REPLACE_Z_MIN_LIMIT/'"$Z_MIN_LIMIT"'/' \
    -e 's/REPLACE_X_MAX_LIMIT/'"$X_MAX_LIMIT"'/' \
    -e 's/REPLACE_Y_MAX_LIMIT/'"$Y_MAX_LIMIT"'/' \
    -e 's/REPLACE_Z_MAX_LIMIT/'"$Z_MAX_LIMIT"'/' \
    -e 's/REPLACE_XY_HOME_OFFSET/'"$XY_HOME_OFFSET"'/' \
    -e 's/REPLACE_Z_HOME_OFFSET/'"$Z_HOME_OFFSET"'/' \
    -e 's/REPLACE_XY_SEARCH_VEL/'"$XY_SEARCH_VEL"'/' \
    -e 's/REPLACE_Z_SEARCH_VEL/'"$Z_SEARCH_VEL"'/' \
    -e 's/REPLACE_XY_LATCH_VEL/'"$XY_LATCH_VEL"'/' \
    -e 's/REPLACE_Z_LATCH_VEL/'"$Z_LATCH_VEL"'/' \
    -e 's/REPLACE_RSC/'"$REPLACE_RSC"'/' \
    -e 's/REPLACE_INC/'"$REPLACE_INC"'/' \
    -e 's/REPLACE_X_PARK/'"$X_PARK"'/' \
    -e 's/REPLACE_Y_PARK/'"$Y_PARK"'/' .TEMP.ini



#create icon
cp .icon.desktop .TEMP.desktop
sed -i -e 's/REPLACE_MACHINE/'"$MACHINE 2016"'/' .TEMP.desktop
cp .TEMP.desktop /home/probotix/Desktop/$MACHINE.desktop







cp .TEMP.ini /home/probotix/linuxcnc/configs/PROBOTIX/probotix.ini
cp .TEMP.hal /home/probotix/linuxcnc/configs/PROBOTIX/probotix.hal
cp .TEMPpostgui.hal /home/probotix/linuxcnc/configs/PROBOTIX/postgui.hal
cp .TEMP.xml /home/probotix/linuxcnc/configs/PROBOTIX/panel.xml
cp .tool.tbl /home/probotix/linuxcnc/configs/PROBOTIX/tool.tbl
cp .emc.nml  /home/probotix/linuxcnc/configs/PROBOTIX/emc.nml
cp .TEMPemc.var  /home/probotix/linuxcnc/configs/PROBOTIX/emc.var
cp .TEMP102.ngc /home/probotix/linuxcnc/nc_files/subs/102.ngc
cp .TEMP100.ngc /home/probotix/linuxcnc/nc_files/subs/100.ngc

rm -f .TEMP*

# To download a package and its dependencies
# sudo apt-get -d install packagename
# packages are downloaded to /var/cache/apt/archives
# To install a downloaded package
# sudo dpkg -i packagename.deb
# To remove a package
# sudo dpkg -r packagename
# To Reconfigure/Repair an installed package
# sudo dpkg-reconfigure packagename
# To check whether a package is install
# sudo dpkg -S packagename

# install glade
# sudo apt-get -d install glade-gtk2


#need to figure out how to capture errors here
#cd .edimax_7811Un_driver/
#sudo insmod 8192cu.ko
#cd ..

#sudo apt-get install libc6 libc6-dev libc6-dbg
#sudo apt-get upgrade
#./SheetCam_setupV6.1.23-32 

clear
echo "PROBOTIX LinuxCNC Configurator Version: $VERSION"
echo "Configuration Complete"
if [ $REBOOT = 1 ]
then
	echo "Please reboot the PC to apply changes."
else
	echo "No need to reboot. Restart LinuxCNC to apply changes."
fi
echo " "
echo "This window will close in 10 seconds"


sleep 10



